; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


;-AIcmd--------------------------------------------------------
[Command]
name = "AI_00"
command = ~a, b, c, x, y, z, D, F, B
time = 0

[Command]
name = "AI_01"
command = ~b, c, x, y, z, D, F, B ,a
time = 0

[Command]
name = "AI_02"
command = ~c, x, y, z, D, F, B ,a, b
time = 0

[Command]
name = "AI_03"
command = ~x, y, z, D, F, B ,a ,b ,c
time = 0

[Command]
name = "AI_04"
command = ~y, z, D, F, B ,a ,b ,c ,x
time = 0

[Command]
name = "AI_05"
command = ~x, y, z, D, F, B ,a ,b ,c
time = 0

[Command]
name = "AI_06"
command = ~y, z, D, F, B ,a ,b ,c ,x
time = 0

[Command]
name = "AI_07"
command = ~z, D, F, B ,a ,b ,c ,x ,y
time = 0

[Command]
name = "AI_08"
command = ~D, F, B ,a ,b ,c ,x ,y ,z
time = 0

[Command]
name = "AI_09"
command = ~F, B ,a ,b ,c ,x ,y ,z ,D
time = 0

[Command]
name = "AI_10"
command = ~B ,a ,b ,c ,x ,y ,z ,D ,F
time = 0

[Command]
name = "AI_11"
command = ~b, c, x, y, z, D, F, B ,a
time = 0

[Command]
name = "AI_12"
command = ~c, x, y, z, D, F, B ,a, b
time = 0

[Command]
name = "AI_13"
command = ~x, y, z, D, F, B ,a ,b ,c
time = 0

[Command]
name = "AI_14"
command = ~y, z, D, F, B ,a ,b ,c ,x
time = 0

[Command]
name = "AI_15"
command = ~x, y, z, D, F, B ,a ,b ,c
time = 0

[Command]
name = "AI_16"
command = ~y, z, D, F, B ,a ,b ,c ,x
time = 0

[Command]
name = "AI_17"
command = ~z, D, F, B ,a ,b ,c ,x ,y
time = 0

[Command]
name = "AI_18"
command = ~D, F, B ,a ,b ,c ,x ,y ,z
time = 0

[Command]
name = "AI_19"
command = ~F, B ,a ,b ,c ,x ,y ,z ,D
time = 0

[Command]
name = "AI_20"
command = ~B ,a ,b ,c ,x ,y ,z ,D ,F
time = 0

[Command]
name = "AI_21"
command = ~b, c, x, y, z, D, F, B ,a
time = 0

[Command]
name = "AI_22"
command = ~c, x, y, z, D, F, B ,a, b
time = 0

[Command]
name = "AI_23"
command = ~x, y, z, D, F, B ,a ,b ,c
time = 0

[Command]
name = "AI_24"
command = ~y, z, D, F, B ,a ,b ,c ,x
time = 0

[Command]
name = "AI_25"
command = ~x, y, z, D, F, B ,a ,b ,c
time = 0

[Command]
name = "AI_26"
command = ~y, z, D, F, B ,a ,b ,c ,x
time = 0

[Command]
name = "AI_27"
command = ~z, D, F, B ,a ,b ,c ,x ,y
time = 0

[Command]
name = "AI_28"
command = ~D, F, B ,a ,b ,c ,x ,y ,z
time = 0

[Command]
name = "AI_29"
command = ~F, B ,a ,b ,c ,x ,y ,z ,D
time = 0

[Command]
name = "AI_30"
command = ~B ,a ,b ,c ,x ,y ,z ,D ,F
time = 0

[Command]
name = "AI_31"
command = ~b, c, x, y, z, D, F, B ,a
time = 0

[Command]
name = "AI_32"
command = ~c, x, y, z, D, F, B ,a, b
time = 0

[Command]
name = "AI_33"
command = ~x, y, z, D, F, B ,a ,b ,c
time = 0

[Command]
name = "AI_34"
command = ~y, z, D, F, B ,a ,b ,c ,x
time = 0

[Command]
name = "AI_35"
command = ~x, y, z, D, F, B ,a ,b ,c
time = 0

[Command]
name = "AI_36"
command = ~y, z, D, F, B ,a ,b ,c ,x
time = 0

[Command]
name = "AI_37"
command = ~z, D, F, B ,a ,b ,c ,x ,y
time = 0

[Command]
name = "AI_38"
command = ~D, F, B ,a ,b ,c ,x ,y ,z
time = 0

[Command]
name = "AI_39"
command = ~F, B ,a ,b ,c ,x ,y ,z ,D
time = 0

[Command]
name = "AI_40"
command = ~B ,a ,b ,c ,x ,y ,z ,D ,F
time = 0


[Command]
name = "AI_41"
command = ~b, c, x, y, z, D, F, B ,a
time = 0

[Command]
name = "AI_42"
command = ~c, x, y, z, D, F, B ,a, b
time = 0

[Command]
name = "AI_43"
command = ~x, y, z, D, F, B ,a ,b ,c
time = 0

[Command]
name = "AI_44"
command = ~y, z, D, F, B ,a ,b ,c ,x
time = 0

[Command]
name = "AI_45"
command = ~x, y, z, D, F, B ,a ,b ,c
time = 0

[Command]
name = "AI_46"
command = ~y, z, D, F, B ,a ,b ,c ,x
time = 0

[Command]
name = "AI_47"
command = ~z, D, F, B ,a ,b ,c ,x ,y
time = 0

[Command]
name = "AI_48"
command = ~D, F, B ,a ,b ,c ,x ,y ,z
time = 0

[Command]
name = "AI_49"
command = ~F, B ,a ,b ,c ,x ,y ,z ,D
time = 0

[Command]
name = "AI_50"
command = ~B ,a ,b ,c ,x ,y ,z ,D ,F
time = 0




;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;

;-| Special Motions |------------------------------------------------------
[Command]
name = "2QCF_b"
command = ~D, DF, F, D, DF, F, b
time = 20

[Command]
name = "2QCF_y"
command = ~D, DF, F, D, DF, F, y
time = 20

[Command]
name = "vism"
command = ~F, D, B, a

[Command]
name = "vism"
command = ~F, D, B, b

[Command]
name = "FDF_a"
command = ~F, D, DF, a

[Command]
name = "FDF_b"
command = ~F, D, DF, b

[Command]
name = "FDF_xy"
command = ~F, D, DF, x+y

[Command]
name = "upper_x"
command = ~F, D, DF, x

[Command]
name = "upper_y"
command = ~F, D, DF, y

[Command]
name = "upper_a"
command = ~F, D, DF, a

[Command]
name = "upper_b"
command = ~F, D, DF, b

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_a"
command = ~D, DF, F, a

[Command]
name = "QCF_b"
command = ~D, DF, F, b

[Command]
name = "QCB_a"
command = ~D, DB, B, a

[Command]
name = "QCB_b"
command = ~D, DB, B, b

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "BF_a"
command = ~60$B, F, a

[Command]
name = "BF_b"
command = ~60$B, F, b

[Command]
name = "BF_x"
command = ~30$B, F, x

[Command]
name = "BF_y"
command = ~30$B, F, y

[Command]
name = "FBF_x"
command = ~F, B, F, x
time = 20

[Command]
name = "FBFB_punch"
command = ~F, B, F, y
time = 20

[Command]
name = "FF_a"
command = F, F, a

[Command]
name = "FF_b"
command = F, F, b

[Command]
name = "xy";Required (do not remove)
command = x+y
time = 1

[Command]
name = "DD_punch"
command = ~D, D, x
time = 20

[Command]
name = "DD_punch"
command = ~D, D, y
time = 20

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[Command]
name = "holda";Required (do not remove)
command = /a
time = 1

[Command]
name = "holdb";Required (do not remove)
command = /b
time = 1
[Command]
name = "holdc";Required (do not remove)
command = /c
time = 1

[Command]
name = "holdx";Required (do not remove)
command = /x
time = 1

[Command]
name = "holdy";Required (do not remove)
command = /y
time = 1
[Command]
name = "holdz";Required (do not remove)
command = /z
time = 1
;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================

[State -1: ChangeState]
type = ChangeState
value = 2000
triggerall = var(59) <= 0
triggerall = command = "2QCF_y"
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 52 || stateno = 101
trigger2 = animelem = 1, >= 1
trigger3 = stateno = 220 && movecontact
trigger4 = stateno = 210 && movecontact
trigger5 = stateno = 230 && movecontact
trigger6 = stateno = 200 && movecontact
trigger7 = stateno = 204 && movecontact
trigger8 = stateno = 250 && movecontact
trigger9 = stateno = 260 && movecontact
trigger10 = stateno = 270 && movecontact
trigger11 = stateno = 400 && movecontact
trigger12 = stateno = 410 && movecontact
trigger13 = stateno = 420 && movecontact
trigger14 = stateno = 450 && movecontact
trigger15 = stateno = 500 && movecontact
trigger15 = stateno = 1110 && movecontact
;_-------------------------------------------------------
; Finish
[State -1,]
type = ChangeState
value = 2100
triggerall = var(59) <= 0
triggerall = (Power >= 3000) && (Var(5) = 0)
triggerall = (Command = "2QCF_b")
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 52 || stateno = 101
trigger2 = animelem = 1, >= 1
trigger3 = stateno = 220 && movecontact
trigger4 = stateno = 210 && movecontact
trigger5 = stateno = 230 && movecontact
trigger6 = stateno = 200 && movecontact
trigger7 = stateno = 204 && movecontact
trigger8 = stateno = 250 && movecontact
trigger9 = stateno = 260 && movecontact
trigger10 = stateno = 270 && movecontact
trigger11 = stateno = 400 && movecontact
trigger12 = stateno = 410 && movecontact
trigger13 = stateno = 420 && movecontact
trigger14 = stateno = 450 && movecontact
trigger15 = stateno = 500 && movecontact
trigger16 = stateno = 1110 && movecontact
trigger17 = stateno = 261 && movecontact
;-----------------------------------------------------------
[State -1, ]
type = ChangeState
value = 2300
triggerall = var(59) <= 0
triggerall = (command = "FBF_x") && (power >= 2000)
trigger1 = (ctrl) && (statetype = S)
trigger2 = (stateno = 1000) && (numhelper(1001) = 1) && (helper(1001), AnimElem = 11, >1)
trigger3 = (stateno = 1200) && (((Anim = 1200) && (AnimElem = 2,>1))  || ((Anim = 1201) && (AnimElem = 1,>1)))
trigger4 = (stateno = 1201) && (((Anim = 1201) && (AnimElem = 2,>1))  || ((Anim = 1200) && (AnimElem = 1,>1)))
trigger5 = (stateno = 1110) && (movecontact)
trigger6 = (StateType = S) && (MoveContact) && (Var(5) > 0)



;-------Air Blast
[State -1,]
type = ChangeState
value = 2500
triggerall = var(59) <= 0
triggerall = (command = "2QCF_y")
triggerall = power >= 1000
trigger1 = (ctrl) && (statetype = A)
trigger2 = (stateno = 600 || stateno = 610 || stateno = 650  || stateno = 660 || stateno = 1600  || stateno = 1601 ) && (movecontact)
trigger3 = (StateType = A) && (MoveContact) && (Var(5) > 0)
;---------------------------------------------------------------------------
;---Sword combo
[State -1, ]
type = ChangeState
value = 1600
triggerall = var(59) <= 0
triggerall = (command = "QCB_y")
trigger1 = (ctrl) && (statetype = S)
trigger2 = (stateno = 200 || stateno = 201 || stateno = 210 || stateno = 211  || stateno = 250 || stateno = 251 || stateno = 260 || stateno = 261 ) && (Movecontact)
trigger3 = (stateno = 400 || stateno = 450) && (movecontact)
trigger4 = (stateno = 1120) && (movecontact)
trigger5 = (StateType = S) && (MoveContact) && (Var(5) > 0)

;---Sword combo
[State -1, ]
type = ChangeState
value = 1601
triggerall = var(59) <= 0
triggerall = (command = "QCB_y")
trigger1 = (stateno = 220) && (Movecontact)
trigger2 = (stateno = 410) && (movecontact)
trigger3 = (stateno = 1110) && (movecontact)
trigger4 = (stateno = 525) && (movecontact)

;-------------------------------------------------------------

;;;Dash--------
[State -1, ]
type = ChangeState
value = 1500
triggerall = var(59) <= 0
triggerall = p2movetype != H
triggerall = (command = "QCF_a")||  (command = "QCF_b")
trigger1 = (ctrl) && (statetype = S)  && (movetype !=A)


; Sword Rush
[State -1, ]
type = ChangeState
value = 1120
triggerall = var(59) <= 0
triggerall = (command = "BF_x") || (command = "BF_y")
trigger1 = (ctrl) && (statetype = S)
trigger2 = (stateno = 200 || stateno = 201 || stateno = 210 || stateno = 211  || stateno = 250 || stateno = 251 || stateno = 260 || stateno = 261) && (Movecontact)
trigger3 = (stateno = 400 || stateno = 410 || stateno = 450) && (movecontact)
trigger4 = (stateno = 1110 && movecontact)
trigger5 = (StateType = S) && (MoveContact) && (Var(5) > 0)
;---------------------------------------------------------------------------
;---Sword combo
[State -1, ]
type = ChangeState
value = 1100
triggerall = var(59) <= 0
triggerall = (command = "QCB_x")
trigger1 = (ctrl) && (statetype = S)
trigger2 = (stateno = 200 || stateno = 201 || stateno = 210 || stateno = 211  || stateno = 250 || stateno = 251 || stateno = 260 || stateno = 261) && (Movecontact)
trigger3 = (stateno = 400 || stateno = 410 || stateno = 450) && (movecontact)
trigger4 = (stateno = 1120) && (movecontact)
trigger5 = (StateType = S) && (MoveContact) && (Var(5) > 0)
;---------------------------------------------------------------------------
;Zanzouken
[State -1, ]
type = ChangeState
value = 700
triggerall = var(59) <= 0
triggerall = (command = "QCB_b")
trigger1 = (ctrl) && (statetype = S)
;---------------------------------------------------------------------------
;;Air Slank Kicks----------------
[State -1, ]
type = ChangeState
value = 1295
triggerall = var(59) <= 0
triggerall = (command = "QCF_b")
trigger1 = (ctrl) && (statetype = A)
trigger2 = (StateType = A) && (MoveContact) && (Var(5) > 0)
;---------------------------------------------------------------------------
[State -1, ]
type = ChangeState
value = 1290
triggerall = var(59) <= 0
triggerall = (command = "QCF_a")
trigger1 = (ctrl) && (statetype = A)
trigger2 = (StateType = A) && (MoveContact) && (Var(5) > 0)
;---------------------------------------------------------------------------
;;;Ground Blast--------
[State -1, ]
type = ChangeState
value = 1200
triggerall = var(59) <= 0
triggerall = (command = "QCF_x")
trigger1 = (ctrl) && (statetype = S)
trigger2 = (stateno = 200 || stateno = 201 || stateno = 210 || stateno = 211  || stateno = 250 || stateno = 251 || stateno = 260 || stateno = 261) && (Movecontact)
trigger3 = (stateno = 400 || stateno = 410 || stateno = 450) && (movecontact)
trigger4 = (StateType = S) && (MoveContact) && (Var(5) > 0)
;---------------------------------------------------------------------------
[State -1, ]
type = ChangeState
value = 1201
triggerall = var(59) <= 0
triggerall = (command = "QCF_y")
trigger1 = (ctrl) && (statetype = S)
trigger2 = (stateno = 200 || stateno = 201 || stateno = 210 || stateno = 211  || stateno = 250 || stateno = 251 || stateno = 260 || stateno = 261) && (Movecontact)
trigger3 = (stateno = 400 || stateno = 410 || stateno = 450) && (movecontact)
trigger4 = (StateType = S) && (MoveContact) && (Var(5) > 0)
;---------------------------------------------------------------------------
;;Air blasts--------
[State -1, ]
type = ChangeState
value = 1250
triggerall = var(59) <= 0
triggerall = (command = "QCF_y")
trigger1 = (ctrl) && (statetype = A)
trigger2 = (stateno = 600 || stateno = 610 || stateno = 650  || stateno = 660 ) && (movecontact)
trigger3 = (StateType = A) && (MoveContact) && (Var(5) > 0)
;---------------------------------------------------------------------------
[State -1, ]
type = ChangeState
value = 1260
triggerall = var(59) <= 0
triggerall = (command = "QCF_x")
trigger1 = (ctrl) && (statetype = A)
trigger2 = (stateno = 600 || stateno = 610 || stateno = 650  || stateno = 660 ) && (movecontact)
trigger3 = (StateType = A) && (MoveContact) && (Var(5) > 0)

;---------------------------------------------------------------------------
;;Explosive kii
[State -1, ]
type = ChangeState
value = 1000
triggerall = var(59) <= 0
triggerall = (command = "DD_punch") && (power >= 500) 
trigger1 = (ctrl) && (statetype = S || statetype = C)
trigger2 = (stateno = 200 || stateno = 201 || stateno = 210 || stateno = 211  || stateno = 250 || stateno = 251 || stateno = 260 || stateno = 261) && (Movecontact)
trigger3 = (stateno = 400 || stateno = 410 || stateno = 450) && (movecontact)
trigger4 = (stateno = 1120) && (movecontact)
trigger5 = (StateType = S) && (MoveContact) && (Var(5) > 0)
;---------------------------------------------------------------------------
;;;;Throwz

[State -1, ]
type = ChangeState
value = 810
triggerall = var(59) <= 0
triggerall = (command = "holdfwd") && (command = "y") && (P2BodyDist X = [0,10]) && (P2Statetype = A) && (P2Movetype != H)
trigger1 = (ctrl) && (statetype = A)
;---------------------------------------------------------------------------
[State -1, ]
type = ChangeState
value = 800
triggerall = var(59) <= 0
triggerall = (command = "holdfwd" || command = "holdback") && (command = "y") && (P2BodyDist X <= 10) && (P2Statetype = S) && (P2Movetype != H)
trigger1 = (ctrl) && (statetype = S)

 ;;------------------------------------------------------------------------
; Counter
[State -1]
type = ChangeState
value = 305
triggerall = var(59) <= 0
triggerall = command = "c" ^^ command = "z"
trigger1 = (stateno = 150 || stateno = 151) && power >= 1000
trigger2 = (stateno = 152 || stateno = 153) && power >= 1000


; teleport backwards
[State -1]
type = ChangeState
value = 360
triggerall = var(59) <= 0
triggerall = command = "recovery" ^^ command = "z"
triggerall = command = "holdback"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 100
trigger3 = stateno = 101
trigger4 = stateno = 102

; teleport
[State -1]
type = ChangeState
value = 361
triggerall = var(59) <= 0
triggerall = command = "recovery" ^^ command = "z"
trigger1 = statetype = S
trigger1 = ctrl

;running tele
[State -1]
type = ChangeState
value = 361
triggerall = var(59) <= 0
triggerall = stateno = 100 || stateno = 101 || stateno = 102
triggerall = ctrl = 0
trigger1 = command = "holdx" && command = "holda"
trigger2 = command = "holdz"
trigger3 = command = "holdc"


; charge---------------------------------------------
[State -1]
type = ChangeState
value = 1900
triggerall = var(59) <= 0
triggerall = statetype = S
triggerall = Power < 3000
triggerall = ctrl = 1
trigger1 = command = "holdb" && command = "holdy"
trigger2 = command = "holdc"
;;;-------------------------------------------------
; 
[State -1]
type = ChangeState
value = 195
triggerall = var(59) <= 0
trigger1 = command = "start"
trigger1 = Vel X = 0
trigger1 = stateno != 195
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
[State -1, ]
type = ChangeState
value = 660
triggerall = var(59) <= 0
triggerall = (command = "b")
trigger1 = (ctrl) && (statetype = A)
trigger2 = (stateno = 600 || stateno = 650) && (movecontact)
;---------------------------------------------------------------------------
[State -1, ]
type = ChangeState
value = 650
triggerall = var(59) <= 0
triggerall = (command = "a")
trigger1 = (ctrl) && (statetype = A)
trigger2 = (stateno = 600) && (movecontact)
;---------------------------------------------------------------------------
[State -1, ]
type = ChangeState
value = 610
triggerall = var(59) <= 0
triggerall = (command = "y")
trigger1 = (ctrl) && (statetype = A)
trigger2 = (stateno = 600 || stateno = 650) && (movecontact)
trigger3 = (StateType = A) && (MoveContact) && (Var(5) > 0)
;---------------------------------------------------------------------------
[State -1, ]
type = ChangeState
value = 600
triggerall = var(59) <= 0
triggerall = (command = "x")
trigger1 = (ctrl) && (statetype = A)
trigger2 = (stateno = 600) && (AnimElem = 2,>12)
trigger3 = (StateType = A) && (MoveContact) && (Var(5) > 0)
;---------------------------------------------------------------------------
; running kicks
[State -1,]
type = ChangeState
value = 560
triggerall = var(59) <= 0
triggerall = stateno = 101
trigger1 = command = "holdb"

[State -1,]
type = ChangeState
value = 550
triggerall = var(59) <= 0
triggerall = stateno = 101
trigger1 = command = "holda"

; running punchs
[State -1,]
type = ChangeState
value = 525
triggerall = var(59) <= 0
triggerall = stateno = 101
trigger1 = command = "holdy"

; _bVLbN (_bV)
[State -1,]
type = ChangeState
value = 420
triggerall = var(59) <= 0
triggerall = stateno = 101
trigger1 = command = "holdx"

;;;;;;;;;;;;;;;ducking kicks

[State -1, ]
type = ChangeState
value = 460
triggerall = var(59) <= 0
triggerall = (command = "b") && (command = "holddown")
trigger1 = (ctrl) && (statetype = C)
trigger2 = (stateno = 200 || stateno = 201 || stateno = 400 || stateno = 450 || stateno = 420) && (movecontact)
trigger3 = (stateno = 550) && (movecontact)
trigger4 = (StateType = C) && (MoveContact) && (Var(5) > 0)
;---------------------------------------------------------------------------
[State -1, ]
type = ChangeState
value = 450
triggerall = var(59) <= 0
triggerall = (command = "a") && (command = "holddown")
trigger1 = (ctrl) && (statetype = C)
trigger2 = (stateno = 200 || stateno = 201 || stateno = 400 || stateno = 420) && (movecontact)
trigger3 = (stateno = 550 || stateno = 1500 || (stateno = 1290 && Vel Y >0 && pos Y >= 0)) && (movecontact)
trigger4 = (StateType = C) && (MoveContact) && (Var(5) > 0)

;---------------------------------------------------------------------------
;;;;;;;;;;;;;;;ducking punches
[State -1, ]
type = ChangeState
value = 220
triggerall = var(59) <= 0
triggerall = (command = "y")   && (command = "holddown")  && (command = "holdfwd")
trigger1 = (ctrl) && (statetype != A)

[State -1, ]
type = ChangeState
value = 420
triggerall = var(59) <= 0
triggerall = (command = "x") && (command = "holddown")
trigger1 = (stateno = 400) && (movehit)
;--------------------------------------------------------------

[State -1, ]
type = ChangeState
value = 410
triggerall = var(59) <= 0
triggerall = (command = "y") && (command = "holddown")
trigger1 = (ctrl) && (statetype = C)
trigger2 = (stateno = 200 || stateno = 201 || stateno = 400 || stateno = 420) && (movecontact)
trigger3 = (stateno = 550 || stateno = 1500 || (stateno = 1290 && Vel Y >0 && pos Y >= 0)) && (movecontact)
trigger4 = (StateType = C) && (MoveContact) && (Var(5) > 0)
;---------------------------------------------------------------------------
[State -1, ]
type = ChangeState
value = 400
triggerall = var(59) <= 0
triggerall = (command = "x") && (command = "holddown")
trigger1 = (ctrl) && (statetype = C)
trigger2 = (stateno = 400) && (AnimElem = 2,>3)
trigger3 = (stateno = 200 || stateno = 201 || stateno = 400) && (movecontact)
trigger4 = (stateno = 550 || stateno = 1500 || (stateno = 1290 && Vel Y >0 && pos Y >= 0)) && (movecontact)
trigger5 = (StateType = C) && (MoveContact) && (Var(5) > 0)
;---------------------------------------------------------------------------
;;;;Standing kicks
[State -1, ]
type = ChangeState
value = 261
triggerall = var(59) <= 0
triggerall = (command = "b") && (command != "holddown") && (P2BodyDist X <= 10)
trigger1 = (ctrl) && (statetype = S)
trigger2 = (stateno = 200 || stateno = 201 || stateno = 210 || stateno = 211  || stateno = 250 || stateno = 251) && (Movecontact)
trigger3 = (StateType = S) && (MoveContact) && (Var(5) > 0)
trigger4 = (stateno = 550 || stateno = 1500 || (stateno = 1290 && Vel Y >0 && pos Y >= 0)) && (movecontact)
;---------------------------------------------------------------------------
[State -1, ]
type = ChangeState
value = 260
triggerall = var(59) <= 0
triggerall = (command = "b") && (command != "holddown")
trigger1 = (ctrl) && (statetype = S)
trigger2 = (stateno = 200 || stateno = 201 || stateno = 210 || stateno = 211  || stateno = 250 || stateno = 251) && (Movecontact)
trigger3 = (stateno = 400 || stateno = 410 || stateno = 450) && (movecontact)
trigger4 = (stateno = 550 || stateno = 1500 || (stateno = 1290 && Vel Y >0 && pos Y >= 0)) && (movecontact)
trigger5 = (StateType = S) && (MoveContact) && (Var(5) > 0)
;---------------------------------------------------------------------------
[State -1, ]
type = ChangeState
value = 251
triggerall = var(59) <= 0
triggerall = (command = "a") && (command != "holddown") && (P2BodyDist X <= 10)
trigger1 = (ctrl) && (statetype = S)
trigger2 = (stateno = 200 || stateno = 201 || stateno = 210 || stateno = 211) && (Movecontact)
trigger3 = (stateno = 400 || stateno = 410 || stateno = 450) && (movecontact)
trigger4 = (stateno = 550 || stateno = 1500 || (stateno = 1290 && Vel Y >0 && pos Y >= 0)) && (movecontact)
trigger5 = (StateType = S) && (MoveContact) && (Var(5) > 0)
;---------------------------------------------------------------------------
[State -1, ]
type = ChangeState
value = 250
triggerall = var(59) <= 0
triggerall = (command = "a") && (command != "holddown")
trigger1 = (ctrl) && (statetype = S)
trigger2 = (stateno = 200 || stateno = 201 || stateno = 210 || stateno = 211 || stateno = 251) && (Movecontact)
trigger3 = (stateno = 400 || stateno = 410 || stateno = 450) && (movecontact)
trigger4 = (stateno = 550 || stateno = 1500 || (stateno = 1290 && Vel Y >0 && pos Y >= 0)) && (movecontact)
trigger5 = (StateType = S) && (MoveContact) && (Var(5) > 0)
;---------------------------------------------------------------------------
;Standing Punches

[State -1, ]
type = ChangeState
value = 220
triggerall = var(59) <= 0
triggerall = (command = "y")
trigger1 = (stateno = 210) && (movehit)


[State -1, ]
type = ChangeState
value = 211
triggerall = var(59) <= 0
triggerall = (command = "y") && (command != "holddown") && (P2BodyDist X <= 10)
trigger1 = (ctrl) && (statetype = S)
trigger2 = (stateno = 200 || stateno = 201) && (AnimElem = 2,>3)
trigger3 = (stateno = 400 || stateno = 450) && (movecontact)
trigger4 = (stateno = 550 || stateno = 1500 || (stateno = 1290 && Vel Y >0 && pos Y >= 0)) && (movecontact)
trigger5 = (StateType = S) && (MoveContact) && (Var(5) > 0)
;---------------------------------------------------------------------------
[State -1, ]
type = ChangeState
value = 210
triggerall = var(59) <= 0
triggerall = (command = "y") && (command != "holddown")
trigger1 = (ctrl) && (statetype = S)
trigger2 = (stateno = 200 || stateno = 201 || stateno = 211) && (Movecontact)
trigger3 = (stateno = 400 || stateno = 410 || stateno = 450) && (movecontact)
trigger5 = (stateno = 550 || stateno = 1500 || (stateno = 1290 && Vel Y >0 && pos Y >= 0)) && (movecontact)
trigger4 = (StateType = S) && (MoveContact) && (Var(5) > 0)
;---------------------------------------------------------------------------
[State -1, ]
type = ChangeState
value = 201
triggerall = var(59) <= 0
triggerall = (command = "x") && (command != "holddown") && (P2BodyDist X <= 10)
trigger1 = (ctrl) && (statetype = S)
trigger2 = (stateno = 201) && (AnimElem = 2,>3)
trigger3 = (stateno = 400) && (movecontact)
trigger4 = (stateno = 550 || stateno = 1500 || (stateno = 1290 && Vel Y >0 && pos Y >= 0)) && (movecontact)
trigger5 = (StateType = S) && (MoveContact) && (Var(5) > 0)
;---------------------------------------------------------------------------
[State -1, ]
type = ChangeState
value = 200
triggerall = var(59) <= 0
triggerall = (command = "x") && (command != "holddown")
trigger1 = (ctrl) && (statetype = S)
trigger2 = (stateno = 200) && (AnimElem = 2,>3)
trigger3 = (stateno = 201) && (movecontact)
trigger4 = (stateno = 400) && (movecontact)
trigger5 = (stateno = 550 || stateno = 1500 || ((stateno = 1290 && Vel Y >0 && pos Y >= 0) && Vel Y >0 && pos Y >= 0)) && (movecontact)
trigger6 = (StateType = S) && (MoveContact) && (Var(5) > 0)
;---------------------------------------------------------------------------
;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = var(59) <= 0
trigger1 = (command = "FF") && (statetype = S) && (ctrl)
;---------------------------------------------------------------------------
;Hop Back
[State -1, Run Back]
type = ChangeState
value = 105
triggerall = var(59) <= 0
trigger1 = (command = "BB") && (statetype = S) && (ctrl)
;---------------------------------------------------------------------------
;AirDash Fwd
[State -1, Fwd]
type = ChangeState
value = 60
triggerall = var(59) <= 0
trigger1 = (command = "FF") && (statetype = A) && (ctrl) && (stateno = 50) && (Vel X >= 0)
;---------------------------------------------------------------------------
;AirDash Back
[State -1, Back]
type = ChangeState
value = 65
triggerall = var(59) <= 0
trigger1 = (command = "BB") && (statetype = A) && (ctrl) && (stateno = 50) && (Vel X <= 0)

;;;;;-----------------------------------------------------------------------
;AI
;;;;;-----------------------------------------------------------------------
[State -3, AI]
type = VarSet
triggerall = var(59) <= 0
triggerall = RoundState = [1,2]
trigger1 = Command = "AI_00"
trigger2 = Command = "AI_01"
trigger3 = Command = "AI_02"
trigger4 = Command = "AI_03"
trigger5 = Command = "AI_04"
trigger6 = Command = "AI_05"
trigger7 = Command = "AI_06"
trigger8 = Command = "AI_07"
trigger9 = Command = "AI_08"
trigger10 = Command = "AI_09"
trigger11 = Command = "AI_10"
trigger12 = Command = "AI_11"
trigger13 = Command = "AI_12"
trigger14 = Command = "AI_13"
trigger15 = Command = "AI_14"
trigger16 = Command = "AI_15"
trigger17 = Command = "AI_16"
trigger18 = Command = "AI_17"
trigger19 = Command = "AI_18"
trigger20 = Command = "AI_19"
trigger21 = Command = "AI_20"
trigger22 = Command = "AI_21"
trigger23 = Command = "AI_22"
trigger24 = Command = "AI_23"
trigger25 = Command = "AI_24"
trigger26 = Command = "AI_25"
trigger27 = Command = "AI_26"
trigger28 = Command = "AI_27"
trigger29 = Command = "AI_28"
trigger30 = Command = "AI_29"
trigger31 = Command = "AI_30"
trigger32 = Command = "AI_31"
trigger33 = Command = "AI_32"
trigger34 = Command = "AI_33"
trigger35 = Command = "AI_34"
trigger36 = Command = "AI_35"
trigger37 = Command = "AI_36"
trigger38 = Command = "AI_37"
trigger39 = Command = "AI_38"
trigger40 = Command = "AI_39"
trigger41 = Command = "AI_40"
trigger42 = Command = "AI_41"
trigger43 = Command = "AI_42"
trigger44 = Command = "AI_43"
trigger45 = Command = "AI_44"
trigger46 = Command = "AI_45"
trigger47 = Command = "AI_46"
trigger48 = Command = "AI_47"
trigger49 = Command = "AI_48"
trigger40 = Command = "AI_49"
trigger51 = Command = "AI_50"
v = 59
value = 2

[State -3]
type = VarRandom
trigger1 = 1
v = 56
range = 0,100

[State -3]
type = VarRandom
trigger1 = 1
v = 57
range = 0,100

[State -3]
type = VarRandom
trigger1 = 1
v = 58
range = 0,100
;;---------------------------------

[State -1,counter]
type = ChangeState
value = 305
triggerall = var(59) >= 1
triggerall = stateno = [150,153]
triggerall = power >= 1500
trigger1 = power < 2800
trigger1 = random = [500,515]
trigger2 = BackEdgeBodyDist <= 30
trigger2 = random = [0,7]





;[State -3, zanzou]
;type = ChangeState
;triggerall = var(59) >= 1
;triggerall = StateType != A
;Triggerall = Ctrl || stateno = 1901
;trigger1 = inguarddist
;trigger1 = p2bodydist X >= 90
;value = 361



[State -1, 󒆃K[h]
type  = ChangeState
value = 132
triggerall = p2movetype = A
triggerall = statetype = A
triggerall = var(59) = 1
triggerall = ctrl
triggerall = stateno != [190,194]
triggerall = p2statetype = A
trigger1 = p2bodydist X = [40,80]
trigger1 = var(58) = [0,69]
trigger2 = p2bodydist X = [-20,39]
trigger2 = var(58) = [0,95]

[State -1, Βn K[h]
type  = ChangeState
value = 130
triggerall = p2movetype = A
triggerall = statetype != A
triggerall = var(59) = 1
triggerall = ctrl
triggerall = stateno != [190,194]
triggerall = p2statetype = S
trigger1 = p2bodydist X = [40,90]
trigger1 = var(58) = [0,39]
trigger2 = p2bodydist X = [-15,39]
trigger2 = var(58) = [10,49]
trigger3 = enemy,teammode = simul
trigger3 = p2bodydist X = [-50,-16]
trigger3 = var(58) = [0,79]
trigger4 = p2bodydist X = [-15,39]
trigger4 = enemy,hitdefattr = S, NA,SA,HA
trigger4 = Random < 300

[State -1, ΋ K[h]
type  = ChangeState
value = 130
triggerall = p2movetype = A
triggerall = statetype != A
triggerall = var(59) = 1
triggerall = ctrl
triggerall = stateno != [190,194]
triggerall = p2statetype = A
trigger1 = p2bodydist X = [40,90]
trigger1 = var(58) = [0,80]
trigger2 = p2bodydist X = [-40,39]
trigger2 = var(58) = [0,90]
trigger3 = p2bodydist X = [-40,39]
trigger3 = enemy,hitdefattr = A, NA,SA,HA
trigger3 = Random < 600

[State -1, Ⴊ݃K[h]
type  = ChangeState
value = 131
triggerall = p2movetype = A
triggerall = statetype != A
triggerall = var(59) = 1
triggerall = ctrl
triggerall = stateno != [190,194]
trigger1 = p2statetype = C
trigger1 = p2bodydist X = [40,85]
trigger1 = var(58) = [0,50]
trigger2 = p2statetype = C
trigger2 = p2bodydist X = [-20,39]
trigger2 = var(58) = [0,79]
trigger3 = p2statetype = S
trigger3 = p2bodydist X = [-15,39]
trigger3 = var(58) = [0,30]
trigger4 = p2statetype = C
trigger4 = enemy,teammode = simul
trigger4 = p2bodydist X = [-50,-16]
trigger4 = var(58) = [0,79]
trigger5 = p2bodydist X = [-20,39]
trigger5 = enemy,hitdefattr = C, NA,SA,HA
trigger5 = Random < 450



[State -3]
type = ChangeState
triggerall = var(59) >= 2
triggerall = RoundState = 2
triggerall = StateType != A
triggerall = power >= 1100
triggerall = stateno != 2000
trigger1 = Ctrl || ((stateno=52||stateno=100)&&animelem=1,>=1)
trigger1 = Random < 100
trigger1 = p2bodydist X >= 31
trigger1 = p2statetype = S
value = 2000


;;;-----------------------------------------------------------------------


;[State -3, obNXebv]
;type = ChangeState
;triggerall = var(59) >= 1
;triggerall = StateType != A
;triggerall = Ctrl || (stateno = [100,101])
;trigger1 = p2bodydist X = [-10,80]
;trigger1 = p2statetype = L
;value = 105

;=====================================================================
[State -1,]
type  = ChangeState
value = 800
triggerall = var(59) >= 1
triggerall = Random  = [35,59]
triggerall = statetype = S
triggerall = ctrl
triggerall = p2bodydist X = [-1,4]
trigger1 = p2statetype != A
trigger1 = p2statetype != L
trigger1 = p2movetype != H


;=============================KEZ========================================
[State -1,vlbgo[Xg]
type = ChangeState
value = 2100
triggerall = var(59) >= 1
triggerall = roundstate = 2
triggerall = power >= 3000
trigger1 = var(58) = [0,89]
trigger1 = stateno = 260
trigger1 = prevstateno = [210,250]
trigger1 = movehit
trigger2 = stateno = 261
trigger2 = prevstateno = 251
trigger2 = movehit
trigger2 = p2bodydist X > 30
trigger2 = var(58) = [0,89]
trigger3 = stateno = 410
trigger3 = prevstateno = 420
trigger3 = movehit
trigger3 = var(58) = [0,9]


[State -1,g]
type = ChangeState
value = 2300
triggerall = var(59) >= 1
triggerall = power >= 2100
triggerall = statetype != A
triggerall = ctrl
triggerall = p2bodydist X < 80
trigger1 = p2statetype = A && vel Y > 1 && p2bodydist Y>-50
trigger1 = var(58) = [90,91]
trigger2 = p2life < 150
trigger2 = random = [400,499]
trigger2 = p2statetype != L
trigger2 = p2movetype != H

[State -1,MbNC]
type = ChangeState
value = 2000
triggerall = var(59) >= 1
triggerall = power >= 1100
triggerall = stateno != 2000
trigger1 = var(58) = [0,89]
trigger1 = stateno = 260
trigger1 = prevstateno = [210,250]
trigger1 = movehit
trigger2 = stateno = 261
trigger2 = prevstateno = 251
trigger2 = movehit
trigger2 = var(58) = [0,89]
trigger2 = p2bodydist X > 30
trigger3 = stateno = 410
trigger3 = prevstateno = 420
trigger3 = movehit
trigger3 = var(58) = [0,9]


[State -1,MbNC]
type = ChangeState
value = 2500
triggerall = var(59) >= 1
triggerall = power >= 1100
triggerall = stateno != 2500
triggerall = var(58) = [0,89]
trigger1 = stateno = 660
trigger1 = movehit
trigger2 = Ctrl
trigger2 = statetype = A
trigger2 = p2movetype = A
trigger2 = p2bodydist X < 100
trigger2 = p2bodydist Y = [0,100]



;;;------------------------------------------------------------------------

; XbV_ELbN()
[State -1,]
type = ChangeState
value = 1291
triggerall = var(59)
triggerall = roundstate = 2
triggerall = statetype = A
trigger1 = movecontact && (stateno = 650)
trigger2 = movecontact && (stateno = 620)
trigger2 = var(58) = [40,89]

; XbV_ELbN()
[State -1,]
type = ChangeState
value = 1290
triggerall = var(59)
triggerall = roundstate = 2
triggerall = statetype = A
triggerall = ctrl
trigger1 = p2bodydist X = [10,100]
trigger1 = p2bodydist Y >= -10
trigger1 = var(58) = [40,89]




[State -1]
type = ChangeState
value = 1500
triggerall = var(59) >= 1
triggerall = statetype != A
triggerall = ctrl
triggerall = p2bodydist X < 100
triggerall = p2statetype != L
trigger1 = Random < 200
trigger1 = p2bodydist X >= 31
trigger1 = p2statetype = S
trigger2 = var(58) = [80,99]
trigger2 = p2stateno != [120,155]

[State -1]
type = ChangeState
value = 1600
triggerall = var(59) >= 1
trigger1 = statetype != A
trigger1 = ctrl
trigger1 = p2statetype = A
trigger1 = p2bodydist X < 150
trigger1 = var(58) = [10,12]
trigger2 = stateno = 260
trigger2 = prevstateno = [210,250]
trigger2 = movehit
trigger2 = var(58) = [0,39]
trigger3 = stateno = 261
trigger3 = movecontact
trigger3 = p2bodydist X > 30
trigger3 = var(58) = [0,39]


[State -1]
type = ChangeState
value = 1601
triggerall = var(59) >= 1
triggerall = statetype != A
trigger1 = stateno = 525
trigger1 = movecontact
trigger1 = p2bodydist X < 150
trigger1 = var(58) = [10,29]
trigger2 = stateno = 220
trigger2 = prevstateno = 210
trigger2 = movecontact
trigger2 = var(58) = [0,29]
trigger3 = stateno = 1110
trigger3 = movecontact
trigger3 = var(58) = [0,19]
trigger4 = stateno = 410
trigger4 = movecontact
trigger4 = var(58) = [0,2]



[State -1]
type = ChangeState
value = 1100
triggerall = var(59) >= 1
trigger1 = statetype != A
trigger1 = ctrl
trigger1 = p2bodydist X < 150
trigger1 = var(58) = [0,4]
trigger2 = stateno = 260
trigger2 = prevstateno = [210,250]
trigger2 = p2bodydist X = [90,120]
trigger2 = movehit
trigger2 = var(58) = [0,39]
trigger3 = stateno = 261
trigger3 = movecontact
trigger3 = p2bodydist X > 30
trigger3 = var(58) = [0,39]
trigger4 = stateno = 410
trigger4 = movecontact
trigger4 = var(58) = [3,4]

[State -1]
type = ChangeState
value = 1120
triggerall = var(59) >= 1
trigger1 = statetype != A
trigger1 = ctrl
trigger1 = p2bodydist X > 150
trigger1 = var(58) = [5,9]
trigger2 = stateno = 260
trigger2 = prevstateno = [210,250]
trigger2 = movehit
trigger2 = p2bodydist X < 120
trigger2 = var(58) = [0,39]
trigger3 = stateno = 261
trigger3 = movecontact
trigger3 = p2bodydist X > 30
trigger3 = var(58) = [0,39]
trigger4 = stateno = 410
trigger4 = movecontact
trigger4 = var(58) = 5
trigger5 = (stateno = (0 ||20||21) ) && time=5
trigger5 = prevstateno = 1110
trigger5 = var(58) = [0,59]
trigger6 = stateno = 261
trigger6 = movecontact
trigger6 = p2bodydist X > 100
trigger6 = var(58) = [0,19]

[State -1]
type = ChangeState
value = 1000
triggerall = var(59) >= 1
triggerall = power >= 600
triggerall = p2bodydist X < 150
trigger1 = statetype != A
trigger1 = ctrl
trigger1 = var(58) = [80,99]
trigger2 = stateno = 260
trigger2 = prevstateno = [210,250]
trigger2 = movehit
trigger2 = var(58) = [0,39]
trigger3 = stateno = 261
trigger3 = movecontact
trigger3 = p2bodydist X > 30
trigger3 = var(58) = [0,39]
trigger4 = stateno = 410
trigger4 = movecontact
trigger4 = var(58) = [20,24]
trigger5 = stateno = 1110
trigger5 = movecontact && animtime=0
trigger5 = var(58) = [0,19]
trigger6 = stateno = 1120
trigger6 = movecontact && animtime=0
trigger6 = var(58) = [0,19]





[State -1]
type = ChangeState
value = 1200
triggerall = var(59) >= 1
triggerall = power >= 100
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl
trigger1 = p2bodydist X > 150
trigger1 = var(58) = [80,82]
trigger2 = stateno = 260
trigger2 = prevstateno = [210,250]
trigger2 = movehit
trigger2 = var(58) = [0,39]
trigger3 = stateno = 261
trigger3 = movecontact
trigger3 = p2bodydist X > 30
trigger3 = var(58) = [0,39]
trigger4 = stateno = 410
trigger4 = movecontact
trigger4 = var(58) = [25,30]

[State -1]
type = ChangeState
value = 1205
triggerall = var(59) >= 1
trigger1 = stateno = 1200  && time >15
trigger1 = var(58) = [0,59]

[State -1]
type = ChangeState
value = 1201
triggerall = var(59) >= 1
triggerall = power >= 100
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl
trigger1 = p2bodydist X > 150
trigger1 = var(58) = [83,85]
trigger2 = stateno = 260
trigger2 = prevstateno = [210,250]
trigger2 = movehit
trigger2 = var(58) = [40,79]
trigger3 = stateno = 261
trigger3 = movecontact
trigger3 = p2bodydist X > 30
trigger3 = var(58) = [40,79]
trigger4 = stateno = 410
trigger4 = movecontact
trigger4 = var(58) = [31,39]

[State -1]
type = ChangeState
value = 1206
triggerall = var(59) >= 1
trigger1 = stateno = 1201   && time >15
trigger1 = var(58) = [0,59]


[State -1,MbNC]
type = ChangeState
value = 1250
triggerall = var(59) >= 1
triggerall = var(58) = [0,89]
triggerall = Ctrl
trigger1 = (stateno = 600 || stateno = 610 || stateno = 650  || stateno = 660 ) && (movecontact)
trigger2 = statetype = A
trigger2 = p2movetype = A
trigger2 = p2bodydist X < 100
trigger2 = p2bodydist Y = [0,100]

[State -1,MbNC]
type = ChangeState
value = 1260
triggerall = var(59) >= 1
triggerall = var(58) = [50,99]
triggerall = Ctrl
trigger1 = (stateno = 600 || stateno = 610 || stateno = 650  || stateno = 660 ) && (movecontact)
trigger2 = statetype = A
trigger2 = p2movetype = A
trigger2 = p2bodydist Y = [0,-50]


[State -1, WvJn]
type = ChangeState
value = 40
triggerall = var(59) >= 1
triggerall = p2bodydist Y < -160
triggerall = statetype = S
triggerall = p2bodydist X< 160
triggerall = ctrl
trigger1 = p2statetype = A
trigger1 = p2movetype = H
trigger1= (prevstateno=1110 )


;;;------------------------Running
[State -1, kick]
type = ChangeState
value = 560
triggerall = stateno = 101
triggerall = var(59) >= 1
trigger1 = p2bodydist x > 120
trigger1 = var(58) = [70,85]

[State -1,slide]
type = ChangeState
value = 550
triggerall = stateno = 101
triggerall = var(59) >= 1
trigger1 = p2bodydist x < 50
trigger1 = var(58) = [0,34]

[State -1,slice up]
type = ChangeState
value = 525
triggerall = stateno = 101
triggerall = var(59) >= 1
trigger1 = p2bodydist x < 50
trigger1 = var(58) = [35,69]

[State -1 , trip]
type = ChangeState
value = 420
triggerall = stateno = 101
triggerall = var(59) >= 1
trigger1 = p2bodydist x = [80,100]
trigger1 = var(58) = [85,99]

;============================ʏZ=========================================
[State -1]
type = ChangeState
value = 201
triggerall = roundstate = 2
triggerall = var(59) >= 1
triggerall = p2bodydist x < 4
triggerall = statetype = S
triggerall = ctrl
trigger1 = random = [0,49]
trigger1 = p2statetype != L
trigger1 = p2movetype != A
trigger2 = var(58) = [0,21]
trigger2 = p2stateno != [120,159]
trigger2 = p2statetype != L
trigger2 = p2movetype = H
trigger3 = p2movetype = I
trigger3 = enemynear,ctrl = 0
trigger3 = ctrl
trigger3 = var(58) = [0,21]
trigger4 = stateno = 420
trigger4 = movecontact
trigger4 = var(58) = [0,9]

[State -1]
type = ChangeState
value = 200
triggerall = roundstate = 2
triggerall = var(59) >= 1
triggerall = p2bodydist x = [4,25]
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = random = [0,149]
trigger1 = p2statetype != L
trigger1 = p2movetype != A
trigger2 = var(58) = [0,21]
trigger2 = p2stateno != [120,159]
trigger2 = p2statetype != L
trigger2 = p2movetype = H
trigger3 = p2movetype = I
trigger3 = enemynear,ctrl = 0
trigger3 = ctrl
trigger3 = var(58) = [0,21]
trigger4 = stateno = (201||420||550)
trigger4 = movecontact
trigger4 = var(58) = [0,89]

[State -1]
type = ChangeState
value = 211
triggerall = roundstate = 2
triggerall = var(59) >= 1
triggerall = p2bodydist x < 8
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = random = [920,950]
trigger2 = stateno = 450
trigger2 = movecontact
trigger2 = prevstateno = 400
trigger2 = var(58) = [0,79]
trigger3 = (stateno = 550 || stateno = 1500 || (stateno = 1290 && Vel Y >0 && pos Y >= 0))
trigger3 = movecontact
trigger3 = var(58) = [10,19]
trigger4 = (stateno = 200 || stateno = 201) && (AnimElem = 2,>3)
trigger4 = movecontact
trigger4 = var(58) = [0,79]

[State -1]
type = ChangeState
value = 220
triggerall = roundstate = 2
triggerall = var(59) >= 1
trigger1 = p2bodydist x = [8,55]
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = random = [900,910]
trigger2 = stateno = 210
trigger2 = movehit
trigger2 = var(58) = [0,27]



[State -1]
type = ChangeState
value = 210
triggerall = roundstate = 2
triggerall = var(59) >= 1
triggerall = p2bodydist x = [8,55]
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = random = [900,919]
trigger2 = stateno = 450
trigger2 = movecontact
trigger2 = prevstateno = 400
trigger2 = var(58) = [0,79]
trigger3 = (stateno = 410)
trigger3 = movecontact
trigger3 = var(58) = [0,79]
trigger4 = (stateno = 200 || stateno=211 || stateno = 201)
trigger4 = movecontact
trigger4 = var(58) = [0,79]



[State -1]
type = ChangeState
value = 251
triggerall = roundstate = 2
triggerall = var(59) >= 1
triggerall = p2bodydist x < 5
triggerall = statetype = S
trigger1 = random = [300,399]
trigger1 = p2statetype != L
trigger1 = p2movetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 450||stateno = 410
trigger2 = movecontact
trigger2 = prevstateno = 400
trigger2 = var(58) = [80,99]
trigger3 = (stateno = 550 || stateno = 1500 || (stateno = 1290 && Vel Y >0 && pos Y >= 0))
trigger3 = movecontact
trigger3 = var(58) = [80,99]
trigger4 = (stateno = 200 || stateno=211 || stateno = 201 ||stateno=210)
trigger4 = movecontact
trigger4 = var(58) = [80,99]

[State -1]
type = ChangeState
value = 250
triggerall = roundstate = 2
triggerall = var(59) >= 1
triggerall = statetype = S
trigger1 = stateno = 450||stateno = 410
trigger1 = movecontact
trigger1 = prevstateno = 400
trigger1 = var(58) = [0,89]
trigger2 = (stateno = 200 || stateno=211 || stateno = 201 ||stateno=251 ||stateno=210)
trigger2 = movecontact
trigger2 = var(58) = [0,89]


[State -1]
type = ChangeState
value = 261
triggerall = roundstate = 2
triggerall = var(59) >= 1
triggerall = p2bodydist x < 25
trigger1 = (stateno = 200 || stateno=211 || stateno = 201 ||stateno=250 || stateno=251 ||stateno=210)
trigger1 = movecontact
trigger1 = var(58) = [0,89]


[State -1]
type = ChangeState
value = 260
triggerall = roundstate = 2
triggerall = var(59) >= 1
triggerall = p2bodydist x < 90
trigger1 = stateno = 450||stateno = 410
trigger1 = movecontact
trigger1 = prevstateno = 400
trigger1 = var(58) = [0,89]
trigger2 = (stateno = 200 || stateno=211 || stateno = 201 ||stateno=250 || stateno=251 ||stateno=210)
trigger2 = movecontact
trigger2 = var(58) = [0,89]


;==========g==================Ⴊ=========================================
[State -1,Ⴊ݋p`]
type = ChangeState
value = 420
triggerall = roundstate = 2
triggerall = var(59) >= 1
trigger1 = (stateno=400)
trigger1 = movehit
trigger1 = var(58) = [0,99]

[State -1,Ⴊ݋p`]
type = ChangeState
value = 400
triggerall = roundstate = 2
triggerall = var(59) >= 1
trigger1 = (stateno = 200 || stateno = 201 ||stateno=400)
trigger1 = movecontact
trigger1 = var(58) = [80,99]
trigger2 = (stateno = 550 || stateno = 1500 || (stateno = 1290 && Vel Y >0 && pos Y >= 0))
trigger2 = movecontact
trigger2 = var(58) = [50,99]

[State -1,Ⴊ݋p`]
type = ChangeState
value = 410
triggerall = roundstate = 2
triggerall = var(59) >= 1
trigger1 = (stateno = 200 || stateno = 201 ||stateno=420)
trigger1 = movecontact
trigger1 = var(58) = [0,89]
trigger2 = (stateno = 550 || stateno = 1500 || (stateno = 1290 && Vel Y >0 && pos Y >= 0))
trigger2 = movecontact
trigger2 = var(58) = [0,89]

[State -1, WvJn]
type = ChangeState
value = 40
triggerall = var(59) >= 1
triggerall = statetype = S
triggerall = ctrl
trigger1 = (stateno = 410 || stateno = 525 )
trigger1 = movehit

[State -1,ႪݎLbN]
type = ChangeState
value = 450
triggerall = roundstate = 2
triggerall = var(59) >= 1
triggerall = statetype != A
triggerall = p2bodydist x < 45
trigger1 = (stateno = 200 || stateno = 201 ||stateno=420)
trigger1 = movecontact
trigger1 = var(58) = [0,89]
trigger2 = (stateno = 550 || stateno = 1500 || (stateno = 1290 && Vel Y >0 && pos Y >= 0))
trigger2 = movecontact
trigger2 = var(58) = [0,89]

[State -1,Ⴊ݋LbN]
type = ChangeState
value = 460
triggerall = roundstate = 2
triggerall = var(59) >= 1
triggerall = statetype != A
trigger1 = (stateno=450)
trigger1 = movecontact
trigger1 = var(58) = [0,89]
trigger2 = (stateno = 550 || stateno = 1500 || (stateno = 1290 && Vel Y >0 && pos Y >= 0))
trigger2 = movecontact
trigger2 = var(58) = [0,89]

;============================󒆋Z=========================================

[State -1,Wvp`]
type = ChangeState
value = 600
triggerall = roundstate = 2
triggerall = var(59) >= 1
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = var(58) = [0,59]
trigger2 = (stateno = 600) && (AnimElem = 2,>12)
trigger2 = var(58) = [0,39]

[State -1,Wvp`]
type = ChangeState
value = 610
triggerall = roundstate = 2
triggerall = var(59) >= 1
trigger1 = statetype = A
trigger1 = (stateno = 600 || stateno = 650)
trigger1 = movecontact
trigger1 = var(58) = [0,9]
trigger2= statetype = A
trigger2 = ctrl = 1
trigger2 = var(58) = [60,69]



[State -1,WvLbN]
type = ChangeState
value = 650
triggerall = roundstate = 2
triggerall = var(59) >= 1
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = var(58) = [70,89]
trigger2 = stateno = 600
trigger2 = movecontact
trigger2 = var(58) = [10,99]

[State -1,WvLbN ()]
type = ChangeState
value = 660
triggerall = roundstate = 2
triggerall = var(59) >= 1
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = var(58) = [90,99]
trigger2 = statetype = A
trigger2 = stateno = 650
trigger2 = movecontact

;============================Z=========================================
[State -1, WvJn]
type = ChangeState
value = 40
triggerall = roundstate = 2
triggerall = var(59) >= 1
triggerall = p2bodydist X > 160
triggerall = statetype = S
triggerall = Random < p2bodydist X
triggerall = ctrl
trigger1 = p2statetype = L
trigger2 = enemy, numproj >= 1

[State -1, OɃWv]
type = VarSet
triggerall = var(59) >= 1
triggerall = Random < (p2bodydist X) * 4
trigger1 = stateno = 40
sysvar(1)  = 1

[State -1, _bV]
type = ChangeState
value = 100
triggerall = var(59) >= 1
trigger1 = statetype != A
trigger1 = ctrl
trigger1 = var(58) = [10,14]

[State -1, 󒆃_bV]
type = ChangeState
value = 110
triggerall = var(59) >= 1
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = p2bodydist X > 100 && vel Y = 0
trigger1 = var(58) = [10,13]

[State -1, obNXebv]
type = ChangeState
value = 105
triggerall = var(59) >= 1
triggerall = statetype != A
triggerall = ctrl
trigger1 = p2stateno = 5120
trigger1 = var(58) = [0,24]

[State -1,ړ ()]
type = ChangeState
value = 360
triggerall = var(59) >= 1
triggerall = statetype != A
triggerall = ctrl
trigger1 = Var(58) = 15
trigger2 = p2stateno = 5120
trigger2 = var(58) = [25,49]

[State -1,ړ (O)]
type = ChangeState
value = 361
triggerall = var(59) >= 1
triggerall = statetype != A
triggerall = ctrl
trigger1 = Var(58) = 16
trigger2 = enemy,Numproj > 0
trigger2 = var(58) = [25,49]
trigger3 = BackEdgeBodyDist <= 30
trigger3 = P2BodyDist X <= 50
trigger3 = var(58) = [0,11]


[State -1,C͗]
type = ChangeState
value = 1900
triggerall = var(59) >= 1
triggerall = statetype != A
triggerall = stateno != 1900
triggerall = Power < 3000
triggerall = ctrl = 1
triggerall = enemy,Numproj <= 0
trigger1 = p2bodydist X > 35
trigger1 = p2statetype = L
trigger1 = Var(58) = [50,52]
trigger2 = p2bodydist X > 150
trigger2 = Var(58) = [50,79]



[State -1,]
type = ChangeState
value = 195
triggerall = var(59) >= 1
trigger1 = Vel X = 0
trigger1 = stateno != 195
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = p2bodydist X > 200
trigger1 = random = [777,780]

[State -1, CPUpI[g^[]
type = Turn
triggerall = roundstate = 2
triggerall = var(59) >= 1
trigger1   = P2BodyDist X < -200
trigger1   = statetype != A
trigger1   = stateno = [200,440]
trigger1   = Time = 1

[State -1, ng]
type = ChangeState
value = 5200
triggerall = stateno = 5050
triggerall = roundstate = 2
triggerall = var(59) >= 1
triggerall = vel Y > 0
triggerall = alive
triggerall = canrecover
triggerall = pos Y < ifelse((anim = [5051,5059])||(anim = [5061,5069]), 0, 25)
triggerall = pos Y >= -20
trigger1   = Random < 50
trigger2   = var(58) = [20,39]
trigger2   = enemy,hitdefattr = SC, AA, AT, AP

[State -1, 󒆎g]
type = ChangeState
value = 5210
triggerall = stateno = 5050
triggerall = roundstate = 2
triggerall = var(59) >= 1
triggerall = vel Y > -1
triggerall = alive
triggerall = canrecover
triggerall = pos Y = [-120,-20)
trigger1   = Random < 30
trigger2   = P2BodyDist X = [-90,90]
trigger2   = var(58) = [30,39]
trigger2   = enemy,hitdefattr = SA, AA, AT, AP



